@@ -1,18 +1,24 @@
+import py.test
 from sqlobject import *
 from sqlobject.sqlbuilder import func
 from sqlobject.main import SQLObjectIntegrityError
-from dbtest import *
-from dbtest import setSQLiteConnectionFactory
+from .dbtest import *
+from .dbtest import setSQLiteConnectionFactory
+
 
 class IterTest(SQLObject):
-    name = StringCol(dbName='name_col')
+    name = StringCol(dbName='name_col', length=200)
+
 
 names = ('a', 'b', 'c')
+
+
 def setupIter():
     setupClass(IterTest)
     for n in names:
         IterTest(name=n)
 
+
 def test_00_normal():
     setupIter()
     count = 0
@@ -20,6 +26,7 @@ def test_00_normal():
         count += 1
     assert count == len(names)
 
+
 def test_00b_lazy():
     setupIter()
     count = 0
@@ -27,12 +34,14 @@ def test_00b_lazy():
         count += 1
     assert count == len(names)
 
+
 def test_01_turn_to_list():
     count = 0
     for test in list(IterTest.select()):
         count += 1
     assert count == len(names)
 
+
 def test_02_generator():
     all = IterTest.select()
     count = 0
@@ -40,23 +49,25 @@ def test_02_generator():
         count += 1
     assert count == len(names)
 
+
 def test_03_ranged_indexed():
     all = IterTest.select()
     count = 0
     for i in range(all.count()):
-        test = all[i]
+        all[i]  # test it's there
         count += 1
     assert count == len(names)
 
+
 def test_04_indexed_ended_by_exception():
     if not supports('limitSelect'):
-        return
+        py.test.skip("limitSelect isn't supported")
     all = IterTest.select()
     count = 0
     try:
         while 1:
-            test = all[count]
-            count = count+1
+            all[count]
+            count = count + 1
             # Stop the test if it's gone on too long
             if count > len(names):
                 break
@@ -64,19 +75,23 @@ def test_04_indexed_ended_by_exception():
         pass
     assert count == len(names)
 
+
 def test_05_select_limit():
     setupIter()
     assert len(list(IterTest.select(limit=2))) == 2
     raises(AssertionError, IterTest.select(limit=2).count)
 
+
 def test_06_contains():
     setupIter()
     assert len(list(IterTest.select(IterTest.q.name.startswith('a')))) == 1
     assert len(list(IterTest.select(IterTest.q.name.contains('a')))) == 1
-    assert len(list(IterTest.select(IterTest.q.name.contains(func.lower('A'))))) == 1
+    assert len(list(IterTest.select(
+        IterTest.q.name.contains(func.lower('A'))))) == 1
     assert len(list(IterTest.select(IterTest.q.name.contains("a'b")))) == 0
     assert len(list(IterTest.select(IterTest.q.name.endswith('a')))) == 1
 
+
 def test_07_contains_special():
     setupClass(IterTest)
     a = IterTest(name='\\test')
@@ -86,34 +101,35 @@ def test_07_contains_special():
     assert list(IterTest.select(IterTest.q.name.contains('%'))) == [b]
     assert list(IterTest.select(IterTest.q.name.endswith('_'))) == [c]
 
+
 def test_select_getOne():
     setupClass(IterTest)
     a = IterTest(name='a')
     b = IterTest(name='b')
     assert IterTest.selectBy(name='a').getOne() == a
-    assert IterTest.select(IterTest.q.name=='b').getOne() == b
+    assert IterTest.select(IterTest.q.name == 'b').getOne() == b
     assert IterTest.selectBy(name='c').getOne(None) is None
     raises(SQLObjectNotFound, 'IterTest.selectBy(name="c").getOne()')
-    b2 = IterTest(name='b')
+    IterTest(name='b')
     raises(SQLObjectIntegrityError, 'IterTest.selectBy(name="b").getOne()')
     raises(SQLObjectIntegrityError, 'IterTest.selectBy(name="b").getOne(None)')
 
+
 def test_selectBy():
     setupClass(IterTest)
-    a = IterTest(name='a')
-    b = IterTest(name='b')
+    IterTest(name='a')
+    IterTest(name='b')
     assert IterTest.selectBy().count() == 2
 
+
 def test_selectBy_kwargs():
     setupClass(IterTest)
-    try:
-        b = IterTest(nonexistant='b')
-    except TypeError:
-        return
-    assert False, "IterTest(nonexistant='b') should raise TypeError"
+    raises(TypeError, IterTest, nonexistant='b')
+
 
 class UniqTest(SQLObject):
-    name = StringCol(dbName='name_col', unique=True)
+    name = StringCol(dbName='name_col', unique=True, length=100)
+
 
 def test_by_uniq():
     setupClass(UniqTest)
@@ -122,11 +138,13 @@ def test_by_uniq():
     assert UniqTest.byName('a') is a
     assert UniqTest.byName('b') is b
 
+
 class Counter2(SQLObject):
 
     n1 = IntCol(notNull=True)
     n2 = IntCol(notNull=True)
 
+
 class TestSelect:
 
     def setup_method(self, meth):
@@ -142,11 +160,12 @@ class TestSelect:
         assert func([c.n1 for c in counters]) == value
 
     def test_1(self):
-        self.accumulateEqual(sum,Counter2.select(orderBy='n1'),
+        self.accumulateEqual(sum, Counter2.select(orderBy='n1'),
                              sum(range(10)) * 10)
 
     def test_2(self):
-        self.accumulateEqual(len,Counter2.select('all'), 100)
+        self.accumulateEqual(len, Counter2.select('all'), 100)
+
 
 def test_select_LIKE():
     setupClass(IterTest)
@@ -157,15 +176,17 @@ def test_select_LIKE():
     assert IterTest.select(LIKE(IterTest.q.name, "sqlb%")).count() == 1
     assert IterTest.select(LIKE(IterTest.q.name, "sqlx%")).count() == 0
 
+
 def test_select_RLIKE():
     setupClass(IterTest)
 
     if IterTest._connection.dbName == "sqlite":
         if not IterTest._connection.using_sqlite2:
-            return
+            py.test.skip("These tests require SQLite v2+")
 
         # Implement regexp() function for SQLite; only works with PySQLite2
         import re
+
         def regexp(regexp, test):
             return bool(re.search(regexp, test))
 
@@ -185,7 +206,14 @@ def test_select_RLIKE():
     assert IterTest.select(RLIKE(IterTest.q.name, "^sqlb.*$")).count() == 1
     assert IterTest.select(RLIKE(IterTest.q.name, "^sqlx.*$")).count() == 0
 
+
 def test_select_sqlbuilder():
     setupClass(IterTest)
     IterTest(name='sqlobject')
-    IterTest.select(IterTest.q.name==u'sqlobject')
+    IterTest.select(IterTest.q.name == u'sqlobject')
+
+
+def test_select_perConnection():
+    setupClass(IterTest)
+    IterTest(name='a')
+    assert not IterTest.select().getOne().sqlmeta._perConnection
